@@ -11,36 +11,37 @@ TextElementGrid = Sequence[Sequence[TextElement]]  # Indexable 2D grid of text e
 class HTMLFormat:
     """ Format parameters for HTML text graphs with CSS. """
 
-    def __init__(self, header:str, footer:str, row_delim:str, cell_delim:str, stylesheet:str):
+    def __init__(self, header:str, footer:str, row_delim:str, cell_delim:str, stylesheet:str) -> None:
         self.header = header          # Header for each graph (not including CSS styles).
         self.footer = footer          # Footer for each graph (not including CSS styles).
         self.row_delim = row_delim    # Delimiter to place between each row.
         self.cell_delim = cell_delim  # Delimiter to place between each cell.
-        self.stylesheet = stylesheet  # CSS stylesheet. Required to stop anchors from behaving as hyperlinks.
+        self.stylesheet = stylesheet  # CSS stylesheet. Required to stop anchor hyperlink behavior at minimum.
 
 
-GRAPH_CSS_CLASS = "stenoGraph"
+# CSS class for the root HTML element in a finished graph.
+ROOT_CSS_CLASS = "stenoGraph"
 
 # Format using preformatted whitespace with normal line breaks.
 # Adds additional styles needed for monospacing.
-STANDARD_FORMAT = HTMLFormat(
-    header=f'<div class="{GRAPH_CSS_CLASS}">',
+HTML_STANDARD = HTMLFormat(
+    header=f'<div class="{ROOT_CSS_CLASS}">',
     footer='</div>',
     row_delim="\n",
     cell_delim="",
-    stylesheet=f'.{GRAPH_CSS_CLASS} {{white-space: pre;}} '
-               f'.{GRAPH_CSS_CLASS} a {{color: black; text-decoration: none;}} ')
+    stylesheet=f'.{ROOT_CSS_CLASS} {{white-space: pre;}} '
+               f'.{ROOT_CSS_CLASS} a {{color: black; text-decoration: none;}} ')
 
 # Format using explicit HTML tables. Useful for browsers that have trouble lining up monospace fonts.
 # Adds additional styles needed for table elements.
-COMPAT_FORMAT = HTMLFormat(
-    header=f'<table class="{GRAPH_CSS_CLASS}"><tr><td>',
+HTML_COMPAT = HTMLFormat(
+    header=f'<table class="{ROOT_CSS_CLASS}"><tr><td>',
     footer='</td></tr></table>',
     row_delim='</td></tr><tr><td>',
     cell_delim='</td><td>',
-    stylesheet=f'.{GRAPH_CSS_CLASS} {{border-spacing: 0;}} '
-               f'.{GRAPH_CSS_CLASS} a {{color: black; text-decoration: none;}} '
-               f'.{GRAPH_CSS_CLASS} td {{padding: 0;}} ')
+    stylesheet=f'.{ROOT_CSS_CLASS} {{border-spacing: 0;}} '
+               f'.{ROOT_CSS_CLASS} a {{color: black; text-decoration: none;}} '
+               f'.{ROOT_CSS_CLASS} td {{padding: 0;}} ')
 
 
 @lru_cache(maxsize=None)
@@ -60,18 +61,18 @@ def _color_style(row:int, index:int, intense:bool) -> str:
 
 
 class HTMLFormatter:
-    """ Formatter for HTML text graphs with CSS. Includes support for colors, boldface, and anchors. """
+    """ Formatter for HTML text grids with CSS. Includes support for colors, boldface, and anchors. """
 
     # HTML escape substitutions.
     _HTML_ESC = {"&": "&amp;", "<": "&lt;", ">": "&gt;"}
 
-    def __init__(self, grid:TextElementGrid, *, compat=False) -> None:
-        self._grid = grid
-        self._format = COMPAT_FORMAT if compat else STANDARD_FORMAT
+    def __init__(self, grid:TextElementGrid, fmt:HTMLFormat) -> None:
+        self._grid = grid  # Text elements to mark up, arranged in a grid for monospaced rendering.
+        self._fmt = fmt    # Formatting parameters for rows, cells, etc.
 
     def format(self, target="", intense=False) -> str:
         """ Format grid elements into a full HTML graph with <target> highlighted. """
-        fmt = self._format
+        fmt = self._fmt
         sections = ['<style>', fmt.stylesheet, '</style>', fmt.header]
         delim = fmt.cell_delim
         row = 0
